@@ -4,8 +4,8 @@ from komolibs.aws.s3.s3_base import S3Base, S3Result
 
 
 class Upload(S3Base):
-    def __init__(self, access_key: str, access_secret: str, region: str):
-        super().__init__(access_key, access_secret, region)
+    def __init__(self):
+        super().__init__()
 
     def upload(self, data: dict, file_name: str, bucket: str) -> S3Result:
         try:
